package com.xinelu.manage.mapper.agencycategory;

import com.xinelu.manage.domain.agencycategory.AgencyCategory;
import com.xinelu.manage.vo.agencycategory.AgencyCategoryVO;

import java.util.List;


/**
 * 机构类别Mapper接口
 *
 * @author xinelu
 * @date 2024-02-26
 */
public interface AgencyCategoryMapper {
    /**
     * 查询机构类别
     *
     * @param id 机构类别主键
     * @return 机构类别
     */
    AgencyCategory selectAgencyCategoryById(Long id);

    /**
     * 查询机构类别列表
     *
     * @param agencyCategory 机构类别
     * @return 机构类别集合
     */
    List<AgencyCategory> selectAgencyCategoryList(AgencyCategory agencyCategory);

    /**
     * 查询机构类别列表
     *
     * @param agencyCategory 机构类别
     * @return 机构类别集合
     */
    List<AgencyCategoryVO> selectAgencyCategoryVOList(AgencyCategory agencyCategory);

    /**
     * 新增机构类别
     *
     * @param agencyCategory 机构类别
     * @return 结果
     */
    int insertAgencyCategory(AgencyCategory agencyCategory);

    /**
     * 修改机构类别
     *
     * @param agencyCategory 机构类别
     * @return 结果
     */
    int updateAgencyCategory(AgencyCategory agencyCategory);

    /**
     * 删除机构类别
     *
     * @param id 机构类别主键
     * @return 结果
     */
    int deleteAgencyCategoryById(Long id);

    /**
     * 批量删除机构类别
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteAgencyCategoryByIds(Long[] ids);
}
